import {Component, effect, inject, model} from '@angular/core';
import {Todo} from "../../shii/dto/models";
import {FormBuilder, FormGroup, ReactiveFormsModule, Validators} from "@angular/forms";
import {DatePipe} from "@angular/common";
import {TodoService} from "../../shii/service/todo.service";

@Component({
  selector: 'app-form',
  imports: [
    ReactiveFormsModule
  ],
  templateUrl: './form.component.html',
  standalone: true,
})
export class FormComponent {
  todo = model<Todo|null>(null);
  form!: FormGroup;
  fb: FormBuilder = inject(FormBuilder);
  todoService: TodoService = inject(TodoService);

  constructor() {
    effect(() => {
      this.form = this.fb.group({
        title: [this.todo()?.title ?? '', Validators.required],
        dueDate: [new DatePipe('en-US').transform(this.todo()?.dueDate ?? '', 'yyyy-MM-dd')],
      });
    });
  }

  save() {
    const id = this.todo()?.id;

    let subscription;

    if (id) {
      subscription = this.todoService.edit({...this.todo(),...this.form.value}, id);
    } else {
      subscription = this.todoService.create({...this.form.value, done: false});
    }

    subscription.subscribe(() => this.todoService.todos.reload());
  }

  clear() {
    this.form.reset();
    this.todo.set(null);
  }
}
